/*
 * Project name:
       BI Hall Click
 * Copyright:
      (c) mikroElektronika, 2014.
 * Revision History:
      20140820:
      - Initial release (RD);
 * Description:
      Bi Hall click is a simple solution for adding a bipolar Hall switch to your design. 
      It carries the Melexis US2882 bipolar Hall-effect switch and a 74LVC1T45 single bit, dual supply transceiver. 
      Bi Hall click communicates with the target board through the mikroBUS INT line. 
      The board is designed to use either a 3.3V or 5V power supply (which also defines the logic level of the output signal).
      A bipolar Hall effect sensor is sensitive to both north and south pole magnetic fields. 
      Bi Hall click outputs a HIGH logic level when exposed to a South Pole magnetic field, and a LOW logic level 
      when exposed to a North Pole magnetic field. When removed from a magnetic field, the logic level stays in its previous state. 
      It's suitable for any application where alternating north and south poles are used to ensure switching. 
      For example, to measure rotary speed by utilizing a ring magnet with north and south poles.

      - RB0 shows state of Bi Hall click outputs, a HIGH logic level when exposed to a South Pole magnetic field,
        and a LOW logic level when exposed to a North Pole magnetic field.
      - PortD count state changes.

 * Test configuration:
     MCU:             PIC18F45K22
                      http://ww1.microchip.com/downloads/en/DeviceDoc/41412F.pdf
     Dev. Board:      EasyPIC v7 Connectivity
                      http://www.mikroe.com/easypic/
     Oscillator:      HS-PLL, 8MHz Crystal, 32MHz MCU Clock
     ext. modules:    BI Hall Click
                      http://www.mikroe.com/click/bi-hall/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
      - Place BI Hall Click board in the mikroBUS socket 1.
      - Set development board J5 jumper according to SMD jumper on click board. By default it's soldered in the 3.3V position.
      - Turn On SW3-2 and SW3-4 switches for PORTB and PORTD LEDs.
*/

char cnt, old_cnt;
char txt[10];

void interrupt() {
  if(INT0IF_bit) {
    cnt++;
    INT0IF_bit = 0;
  }
}

void main() {
   ANSELB  = 0;                // Configure portB pins as digital
   ANSELD  = 0;                // Configure portD pins as digital
   TRISB   = 0x01;             // Configure RB0 pin as input
   TRISD   = 0;                // Configure portD pins as output
   LATB    = 0x00;             // Reset PortB
   LATD    = 0;                // Reset PortD
   cnt     = 0;
   old_cnt = cnt;

   //IPEN_bit = 1;
   INT0IE_bit  = 1;            // Enable interrupts on RB0
   INTEDG0_bit = 0;            // Interrupt on falling age
   GIE_bit     = 1;
   PEIE_bit    = 1;
   //INT0IE_bit = 1;
   
   while(1) {
      if (old_cnt != cnt) {
         PORTD = cnt;
         old_cnt = cnt;
      }
   }
}